@@ -4,11 +4,8 @@ from decimal import Decimal
 
 from trytond.pool import PoolMeta
 
-__all__ = ['Sale']
 
-
-class Sale:
-    __metaclass__ = PoolMeta
+class Sale(metaclass=PoolMeta):
     __name__ = 'sale.sale'
 
     def _get_carrier_context(self):
@@ -22,10 +19,9 @@ class Sale:
         amount = 0
         for line in self.lines or []:
             if (getattr(line, 'unit_price', None)
-                    and getattr(line, 'quantity', None)
+                    and (getattr(line, 'quantity') or 0) > 0
                     and not getattr(line, 'shipment_cost', None)):
-                amount += (line.unit_price
-                    * Decimal(str(line.quantity or 0)))
+                amount += line.unit_price * Decimal(str(line.quantity))
         context['amount'] = amount
         context['currency'] = self.currency.id
         return context
